@@ -3,11 +3,10 @@ import os
 import shutil
 
 from mcli import config
-from mcli.api.utils.nuke_db import nuke_db
 from mcli.utils.utils_interactive import query_yes_no
 
 
-def clean_mcli(remove_db: bool = False, **kwargs) -> int:
+def clean_mcli(**kwargs) -> int:
     del kwargs
     if not os.path.exists(config.MCLI_CONFIG_DIR):
         print('Already clean!')
@@ -29,11 +28,5 @@ def clean_mcli(remove_db: bool = False, **kwargs) -> int:
             shutil.rmtree(config.MCLI_BACKUP_CONFIG_DIR)
     shutil.move(str(config.MCLI_CONFIG_DIR), str(config.MCLI_BACKUP_CONFIG_DIR))
 
-    if remove_db:
-        print('Nuking the DB')
-        success = nuke_db()
-        if success:
-            print('Wiping DB Successful')
-
     print('All clean!')
     return 0
