@@ -3,9 +3,10 @@ import argparse
 import logging
 import textwrap
 
+from mcli.cli.m_create.cluster import CLUSTER_EXAMPLES, configure_cluster_argparser, create_new_cluster
 from mcli.cli.m_create.env_var import configure_env_var_argparser, create_new_env_var
-from mcli.cli.m_create.platform import PLATFORM_EXAMPLES, configure_platform_argparser, create_new_platform
 from mcli.cli.m_create.secret import configure_secret_argparser, create_new_secret
+from mcli.config import FeatureFlag, MCLIConfig
 
 logger = logging.getLogger(__name__)
 
@@ -22,44 +23,40 @@ def add_common_arguments(parser: argparse.ArgumentParser):
 
 
 def configure_argparser(parser: argparse.ArgumentParser) -> argparse.ArgumentParser:
+    conf = MCLIConfig.load_config(safe=True)
+
     subparsers = parser.add_subparsers(title='MCLI Objects',
                                        description='The table below shows the objects that you can create',
                                        help='DESCRIPTION',
                                        metavar='OBJECT')
     parser.set_defaults(func=create)
 
-    # TODO (HEK-473): Add back when projects are updated to new spec
-    # project_parser = subparsers.add_parser(
-    #     'project',
-    #     help='Create a project to set simplify run defaults',
-    # )
-    # project_parser.set_defaults(func=create_new_project)
+    if not conf.feature_enabled(FeatureFlag.USE_MCLOUD):
+        # pylint: disable=invalid-name
+        CLUSTER_DESC = textwrap.dedent("""
+                                        Add a new cluster in which you can launch runs. If you do not know the appropriate
+                                        context, running `mcli create cluster` alone will give you a list of options to
+                                        choose from.""")
 
-    # pylint: disable=invalid-name
-    PLATFORM_DESC = textwrap.dedent("""
-                                    Add a new platform in which you can launch runs. If you do not know the appropriate
-                                    context, running `mcli create platform` alone will give you a list of options to
-                                    choose from.""")
+        cluster_parser = subparsers.add_parser('cluster',
+                                               aliases=['clusters', 'platforms', "platform"],
+                                               help='Add a cluster to launch runs in',
+                                               description=CLUSTER_DESC,
+                                               epilog=CLUSTER_EXAMPLES,
+                                               formatter_class=argparse.RawDescriptionHelpFormatter)
+        configure_cluster_argparser(cluster_parser)
+        add_common_arguments(cluster_parser)
+        cluster_parser.set_defaults(func=create_new_cluster)
 
-    platform_parser = subparsers.add_parser('platform',
-                                            aliases=['platforms'],
-                                            help='Add a platform to launch runs in',
-                                            description=PLATFORM_DESC,
-                                            epilog=PLATFORM_EXAMPLES,
-                                            formatter_class=argparse.RawDescriptionHelpFormatter)
-    configure_platform_argparser(platform_parser)
-    add_common_arguments(platform_parser)
-    platform_parser.set_defaults(func=create_new_platform)
-
-    environment_parser = subparsers.add_parser(
-        'env',
-        aliases=['envs'],
-        help='Create environment variables to use across your runs',
-        description='Setup environment variables that will be used in all of your subsequent workloads',
-    )
-    configure_env_var_argparser(environment_parser)
-    add_common_arguments(environment_parser)
-    environment_parser.set_defaults(func=create_new_env_var)
+        environment_parser = subparsers.add_parser(
+            'env',
+            aliases=['envs'],
+            help='Create environment variables to use across your runs',
+            description='Setup environment variables that will be used in all of your subsequent workloads',
+        )
+        configure_env_var_argparser(environment_parser)
+        add_common_arguments(environment_parser)
+        environment_parser.set_defaults(func=create_new_env_var)
 
     # pylint: disable-next=invalid-name
     SECRET_EXAMPLES = textwrap.dedent("""
@@ -80,7 +77,8 @@ def configure_argparser(parser: argparse.ArgumentParser) -> argparse.ArgumentPar
         formatter_class=argparse.RawDescriptionHelpFormatter,
     )
     configure_secret_argparser(secrets_parser, secret_handler=create_new_secret)
-    secrets_parser.set_defaults(func=create_new_secret)
+    # Secret creation only happens through subparsers, so just print help if a subparser isn't specified
+    secrets_parser.set_defaults(func=lambda **kwargs: secrets_parser.print_help())
 
     return parser
 
