@@ -4,19 +4,21 @@ import logging
 import textwrap
 from typing import Callable, Optional
 
-from mcli.config import MESSAGE, MCLIConfig, MCLIConfigError
-from mcli.models import MCLIPlatform, MCLISecret, SecretType
+from mcli.api.exceptions import cli_error_handler
+from mcli.api.secrets import create_secret as api_create_secret
+from mcli.config import FeatureFlag, MCLIConfig
+from mcli.models import Cluster, Secret, SecretType
+from mcli.objects.secrets.cluster_secret import ClusterSecret, SecretManager
 from mcli.objects.secrets.create.docker_registry import DockerSecretCreator
+from mcli.objects.secrets.create.gcp import GCPSecretCreator
 from mcli.objects.secrets.create.generic import EnvVarSecretCreator, FileSecretCreator
+from mcli.objects.secrets.create.oci import OCISecretCreator
 from mcli.objects.secrets.create.s3 import S3SecretCreator
 from mcli.objects.secrets.create.ssh import SSHSecretCreator
-from mcli.objects.secrets.platform_secret import PlatformSecret, SecretManager
-from mcli.utils.utils_interactive import InputDisabledError, ValidationError, input_disabled
-from mcli.utils.utils_logging import FAIL, OK, console
+from mcli.utils.utils_interactive import input_disabled
+from mcli.utils.utils_logging import OK, console
 
 logger = logging.getLogger(__name__)
-INPUT_DISABLED_MESSAGE = ('Incomplete secret. Please provide the full set of arguments if running with '
-                          '`--no-input`. Check `mcli create secret --help` for more information.')
 
 CREATORS = {
     SecretType.docker_registry: DockerSecretCreator,
@@ -25,110 +27,115 @@ CREATORS = {
     SecretType.ssh: SSHSecretCreator,
     SecretType.git: SSHSecretCreator,
     SecretType.sftp: SSHSecretCreator,
-    SecretType.s3_credentials: S3SecretCreator,
+    SecretType.s3: S3SecretCreator,
+    SecretType.gcp: GCPSecretCreator,
+    SecretType.oci: OCISecretCreator,
 }
 
 
+def _create_new_secret(
+    secret_type: SecretType,
+    secret_name: Optional[str] = None,
+    no_input: bool = False,
+    **kwargs,
+):
+
+    command = secret_type.value.replace('_', '-')
+
+    @cli_error_handler(f'mcli create secret {command}')
+    def helper():
+        kwargs.pop('func', None)
+
+        with input_disabled(no_input):
+            creator = CREATORS[secret_type]()
+            secret = creator.create(name=secret_name, **kwargs)
+
+            conf: MCLIConfig = MCLIConfig.load_config()
+            if conf.feature_enabled(FeatureFlag.USE_MCLOUD):
+                with console.status('Creating secrets..'):
+                    api_create_secret(secret=secret, timeout=None)
+            else:
+                sync_secret(secret)
+
+            logger.info(f'{OK} Created {secret.secret_type} secret: {secret.name}')
+            return 0
+
+    return helper()
+
+
 def create_new_secret(
     secret_type: SecretType,
     secret_name: Optional[str] = None,
     no_input: bool = False,
     **kwargs,
 ) -> int:
-    kwargs.pop('func', None)
-
-    with input_disabled(no_input):
-        try:
-            creator = CREATORS[secret_type]()
-            secret = creator.create(name=secret_name, **kwargs)
-            logger.info(f'{OK} Created secret: {secret.name}')
-            sync_secret(secret)
-            logger.info(f'{OK} Synced to all platforms')
-        except MCLIConfigError:
-            logger.error(MESSAGE.MCLI_NOT_INITIALIZED)
-            return 1
-        except InputDisabledError:
-            logger.error(INPUT_DISABLED_MESSAGE)
-            return 1
-        except ValidationError as e:
-            logger.error(f'{FAIL} {e}')
-            return 1
-
-    return 0
+    return _create_new_secret(secret_type, secret_name, no_input, **kwargs)
 
 
+@cli_error_handler('mcli create secret shared')
 def copy_existing_secret(
     secret_name: str,
-    platform_name: str,
+    cluster_name: str,
     namespace: str,
     **kwargs,
 ):
-    """Copy an existing secret to the user's platforms
+    """Copy an existing secret to the user's clusters
 
     Args:
         secret_name: Name of secret in a shared namespace
-        platform_name: Name of the platform in which the secret is stored
+        cluster_name: Name of the cluster in which the secret is stored
         namespace: Namespace in which the shared secret lives
     """
     del kwargs
 
-    try:
+    conf = MCLIConfig.load_config()
 
-        conf = MCLIConfig.load_config()
+    # Check that the cluster exists
+    mcli_cluster: Optional[Cluster] = None
+    for pl in conf.clusters:
+        if pl.name == cluster_name:
+            mcli_cluster = pl
+            break
 
-        # Check that the platform exists
-        mcli_platform: Optional[MCLIPlatform] = None
-        for pl in conf.platforms:
-            if pl.name == platform_name:
-                mcli_platform = pl
-                break
+    if mcli_cluster is None:
+        cluster_names = {pl.name for pl in conf.clusters}
+        raise RuntimeError(
+            f'Invalid cluster: Cluster must be one of {sorted(list(cluster_names))}. Got: {cluster_name}')
 
-        if mcli_platform is None:
-            platform_names = {pl.name for pl in conf.platforms}
-            raise ValueError(
-                f'Invalid platform: Platform must be one of {sorted(list(platform_names))}. Got: {platform_name}')
+    # Get available secrets from new cluster
+    manager = SecretManager(
+        Cluster(name=cluster_name, kubernetes_context=mcli_cluster.kubernetes_context, namespace=namespace))
+    available_secrets = manager.get_secrets()
+    logger.debug(f'Found {len(available_secrets)} secrets in cluster {cluster_name}')
 
-        # Get available secrets from new platform
-        manager = SecretManager(
-            MCLIPlatform(name=platform_name, kubernetes_context=mcli_platform.kubernetes_context, namespace=namespace))
-        available_secrets = manager.get_secrets()
-        logger.debug(f'Found {len(available_secrets)} secrets in platform {platform_name}')
+    # Check if secret exists
+    new_secret: Optional[Secret] = None
+    for cluster_secret in available_secrets:
+        if cluster_secret.secret.name == secret_name:
+            new_secret = cluster_secret.secret
+            break
 
-        # Check if secret exists
-        new_secret: Optional[MCLISecret] = None
-        for platform_secret in available_secrets:
-            if platform_secret.secret.name == secret_name:
-                new_secret = platform_secret.secret
-                break
+    if new_secret is None:
+        raise RuntimeError(f'Secret not found: Could not find secret {secret_name} in {namespace} namespace of cluster '
+                           f'{cluster_name}. Please double-check these values.')
 
-        if new_secret is None:
-            raise ValueError(
-                f'Secret not found: Could not find secret {secret_name} in {namespace} namespace of platform '
-                f'{platform_name}. Please double-check these values.')
-
-        # Sync secret to user's platforms
-        logger.info(f'{OK} Copying existing secret: {secret_name}')
-        sync_secret(new_secret)
-        logger.info(f'{OK} Synced to all platforms')
-    except MCLIConfigError:
-        logger.error(MESSAGE.MCLI_NOT_INITIALIZED)
-        return 1
-    except ValueError as e:
-        logger.error(f'{FAIL} {e}')
-        return 1
+    # Sync secret to user's clusters
+    logger.info(f'{OK} Copying existing secret: {secret_name}')
+    sync_secret(new_secret)
+    logger.info(f'{OK} Synced to all clusters')
     return 0
 
 
-def sync_secret(secret: MCLISecret):
+def sync_secret(secret: Secret):
     conf = MCLIConfig.load_config()
 
-    # Sync to all known platforms
-    platform_secret = PlatformSecret(secret)
-    with console.status('Creating secret in all platforms...') as status:
-        for platform in conf.platforms:
-            with MCLIPlatform.use(platform):
-                status.update(f'Creating secret in platform: {platform.name}...')
-                platform_secret.create(platform.namespace)
+    # Sync to all known clusters
+    cluster_secret = ClusterSecret(secret)
+    with console.status('Creating secret in all cluster...') as status:
+        for cluster in conf.clusters:
+            with Cluster.use(cluster):
+                status.update(f'Creating secret in cluster: {cluster.name}...')
+                cluster_secret.create(cluster.namespace)
 
 
 def _add_common_arguments(parser: argparse.ArgumentParser):
@@ -158,6 +165,7 @@ def _add_docker_registry_subparser(
     """
     docker_registry_parser = subparser.add_parser(
         'docker',
+        aliases=['docker-registry'],
         help='Create a secret to let you pull images from a private Docker registry.',
         description='Create a secret to let you pull images from a private Docker registry.',
         epilog=DOCKER_EXAMPLES,
@@ -362,6 +370,7 @@ def _add_env_var_subparser(
     """
     generic_env_parser = subparser.add_parser(
         'env',
+        aliases=['environment'],
         help='Create a secret that will be exposed as an environment variable',
         description='Create a secret that will be exposed as an environment variable. This lets you easily use '
         'arbitrary confidential information within your workloads.',
@@ -377,6 +386,78 @@ def _add_env_var_subparser(
     generic_env_parser.set_defaults(func=secret_handler, secret_type=SecretType.environment)
 
 
+def _add_oci_subparser(
+    subparser: argparse._SubParsersAction,
+    secret_handler: Callable,
+):
+    # pylint: disable-next=invalid-name
+    DESCRIPTION = """
+        Add your OCI config file and key pem file to MCLI for use in your workloads. 
+        
+        Basically you would need a RSA key pair (API signing key) to use OCI through CLI or SDK. You would also need a config file that would contain
+        the required configuration information like user credentials and tenancy OCID.
+
+        The steps to generate these keys and config file can be found here: 
+        https://docs.oracle.com/en-us/iaas/Content/API/Concepts/apisigningkey.htm#apisigningkey_topic_How_to_Generate_an_API_Signing_Key_Console
+        AND
+        https://docs.oracle.com/en-us/iaas/Content/API/Concepts/sdkconfig.htm
+
+        A sample config file would look like:
+
+        [DEFAULT]
+        user=ocid1.user.oc1..<unique_ID>
+        fingerprint=<your_fingerprint>
+        key_file=~/.oci/oci_api_key.pem
+        tenancy=ocid1.tenancy.oc1..<unique_ID>
+        region=us-ashburn-1
+
+        The key file is a PEM file that would look like a typical RSA private key file.
+
+        Once you create the config and API private key pem file (note that the public key isn't needed as its fingerprint should already exist in the generated
+        config file), you can create a OCI secret for MCLI. MCLI will automatically mount it to your workloads and export two environment variables:
+
+        $OCI_CLI_CONFIG_FILE: Path to your config file.
+        $OCI_CLI_KEY_FILE: Path to your API signing private key file.
+
+        Most OCI compliant libraries will use these environment variables to discover your configs by default.
+    """
+    # pylint: disable-next=invalid-name
+    EXAMPLES = """
+
+        Examples:
+
+        # Add your OCI secret interactively
+        > mcli create secret oci
+        ? What would you like to name this secret? my-oci-configs
+        ? Where is your OCI config file located? ~/.oci/config
+        ? Where is your OCI API key file located? ~/.oci/oci_api_key.pem
+        ✔  Created secret: my-oci-configs
+        ✔  Synced to all clusters
+
+        # Add your oci secret using arguments
+        > mcli create secret oci --name my-oci-configs --config-file ~/.oci/config --key-file ~/.oci/oci_api_key.pem
+    """
+    oci_configs_parser = subparser.add_parser(
+        'oci',
+        help='Add your OCI config and API key to MCLI',
+        description=DESCRIPTION,
+        epilog=EXAMPLES,
+        formatter_class=argparse.RawDescriptionHelpFormatter,
+    )
+    _add_common_arguments(oci_configs_parser)
+    oci_configs_parser.add_argument('--config-file',
+                                    metavar='PATH',
+                                    help='Path to your OCI config file. Usually `~/.oci/config`')
+    oci_configs_parser.add_argument('--key-file',
+                                    metavar='PATH',
+                                    help='Path to your OCI API key file. Usually `~/.oci/oci_api_key.pem`')
+    oci_configs_parser.add_argument(
+        '--mount-directory',
+        metavar='PATH',
+        help='Location in your workload at which your key and config files will be mounted.')
+    oci_configs_parser.set_defaults(func=secret_handler, secret_type=SecretType.oci)
+
+
 def _add_s3_subparser(
     subparser: argparse._SubParsersAction,
     secret_handler: Callable,
@@ -426,7 +507,7 @@ Examples:
 ? Where is your S3 config file located? ~/.aws/config
 ? Where is your S3 credentials file located? ~/.aws/credentials
 ✔  Created secret: my-s3-credentials
-✔  Synced to all platforms
+✔  Synced to all clusters
 
 # Add your s3 secret using arguments
 > mcli create secret s3 --name my-s3-credentials --config-file ~/.aws/config --credentials-file ~/.aws/credentials
@@ -439,6 +520,7 @@ Examples:
         epilog=EXAMPLES,
         formatter_class=argparse.RawDescriptionHelpFormatter,
     )
+    _add_common_arguments(s3_cred_parser)
     s3_cred_parser.add_argument('--config-file',
                                 metavar='PATH',
                                 help='Path to your S3 config file. Usually `~/.aws/config`')
@@ -449,8 +531,55 @@ Examples:
         '--mount-directory',
         metavar='PATH',
         help='Location in your workload at which your credentials and config files will be mounted')
-    _add_common_arguments(s3_cred_parser)
-    s3_cred_parser.set_defaults(func=secret_handler, secret_type=SecretType.s3_credentials)
+    s3_cred_parser.set_defaults(func=secret_handler, secret_type=SecretType.s3)
+
+
+def _add_gcp_subparser(
+    subparser: argparse._SubParsersAction,
+    secret_handler: Callable,
+):
+    # pylint: disable-next=invalid-name
+    DESCRIPTION = """
+Add your GCP config file and credentials file to MCLI for use in your workloads.
+
+Once you've created a GCP secret, MCLI will automatically mount it to your workloads
+and export the following environment variable:
+
+$GOOGLE_APPLICATION_CREDENTIALS: Path to your credentials file
+
+Most gcp-compliant libraries will use this environment variable to discover your
+credentials by default.
+    """
+
+    # pylint: disable-next=invalid-name
+    EXAMPLES = """
+
+Examples:
+
+# Add your gcp secret interactively
+> mcli create secret gcp
+? What would you like to name this secret? my-gcp-credentials
+? Where is your GCP credentials file located? <my_gcp_credentials.json>
+✔  Created secret: my-gcp-credentials
+✔  Synced to all clusters
+
+# Add your gcp secret using arguments
+> mcli create secret gcp --name my-gcp-credentials --credentials-file <my_gcp_credentials.json>
+
+    """
+    gcp_cred_parser = subparser.add_parser(
+        'gcp',
+        help='Add your GCP credentials to MCLI',
+        description=DESCRIPTION,
+        epilog=EXAMPLES,
+        formatter_class=argparse.RawDescriptionHelpFormatter,
+    )
+    _add_common_arguments(gcp_cred_parser)
+    gcp_cred_parser.add_argument('--credentials-file', metavar='PATH', help='Path to your GCP credentials file.')
+    gcp_cred_parser.add_argument('--mount-path',
+                                 metavar='PATH',
+                                 help='Location in your workload at which your credentials files will be mounted')
+    gcp_cred_parser.set_defaults(func=secret_handler, secret_type=SecretType.gcp)
 
 
 def _add_shared_subparser(subparser: argparse._SubParsersAction,):
@@ -459,9 +588,13 @@ def _add_shared_subparser(subparser: argparse._SubParsersAction,):
 
     Examples:
 
-    # Add a shared s3 secret from the rxzx platform
-    mcli create secret shared --name streaming-credentials-s3 --platform rxzx --namespace shared-namespace
+    # Add a shared s3 secret from the rxzx cluster
+    mcli create secret shared --name streaming-credentials-s3 --cluster rxzx --namespace shared-namespace
     """
+    conf = MCLIConfig.load_config(safe=True)
+    if conf.feature_enabled(FeatureFlag.USE_MCLOUD):
+        # shared secrets not supported in mcloud
+        return
 
     shared_parser = subparser.add_parser(
         'shared',
@@ -476,16 +609,15 @@ def _add_shared_subparser(subparser: argparse._SubParsersAction,):
                                help='Name of an existing secret',
                                metavar='NAME')
 
-    conf = MCLIConfig.load_config(safe=True)
-    platform_names = sorted([pl.name for pl in conf.platforms])
+    cluster_names = sorted([pl.name for pl in conf.clusters])
     shared_parser.add_argument(
+        '--cluster',
         '--platform',
-        dest='platform_name',
+        dest='cluster_name',
         required=True,
-        choices=platform_names,
-        metavar='PLATFORM',
-        help=f'Name of the platform that contains the secret. Choices: {", ".join(platform_names)}')
-
+        choices=cluster_names,
+        metavar='CLUSTER',
+        help=f'Name of the cluster that contains the secret. Choices: {", ".join(cluster_names)}')
     shared_parser.add_argument('--namespace', required=True, help='Namespace that contains the secret')
     shared_parser.set_defaults(func=copy_existing_secret)
 
@@ -521,5 +653,11 @@ def configure_secret_argparser(
     # S3 credentials
     _add_s3_subparser(subparser, secret_handler)
 
+    # GCP credentials
+    _add_gcp_subparser(subparser, secret_handler)
+
+    # OCI credentials
+    _add_oci_subparser(subparser, secret_handler)
+
     # Shared secret
     _add_shared_subparser(subparser)
