@@ -1,6 +1,7 @@
 """Helpers for `mcli get` displays"""
 import datetime
 import json
+import logging
 from abc import ABC, abstractmethod
 from dataclasses import dataclass, fields
 from enum import Enum
@@ -12,6 +13,8 @@ from rich.table import Table
 from mcli.utils.utils_logging import console, err_console
 from mcli.utils.utils_rich import create_table
 
+logger = logging.getLogger(__name__)
+
 
 class OutputDisplay(Enum):
     TABLE = 'table'
@@ -29,7 +32,6 @@ class OutputDisplay(Enum):
 class MCLIDisplayItem():
     """Item for display in an `mcli get` list of items
     """
-    name: str
 
     def to_dict(self) -> Dict[str, Any]:
         """Get the current object as a dictionary
@@ -72,11 +74,19 @@ class MCLIGetDisplay(ABC):
         """
         return None
 
+    @property
+    def index_label(self) -> str:
+        return "name"
+
+    def create_custom_table(self, columns: List[str], data: List[Any]) -> Optional[Table]:  # pylint: disable=unused-argument
+        """Override for custom create display table formatting"""
+        return None
+
     def print(self, output: OutputDisplay):
         items = self.get_list()
         if output == OutputDisplay.TABLE:
             if not items:
-                err_console.print('None')
+                err_console.print('No items found.')
                 return
             disp = self.to_table(items)
         elif output == OutputDisplay.NAME:
@@ -97,15 +107,22 @@ class MCLIGetDisplay(ABC):
         def _to_str(obj: Any) -> str:
             return yaml.safe_dump(obj, default_flow_style=None).strip() if not isinstance(obj, str) else obj
 
-        column_names = self.override_column_ordering or [key for key, val in items[0].items() if val and key != 'name']
+        column_names = self.override_column_ordering or [
+            key for key, val in items[0].items() if val and key != self.index_label
+        ]
         columns, names = [], []
         for item in items:
-            names.append(item['name'])
+            if self.index_label:
+                names.append(item[self.index_label])
             columns.append(tuple(_to_str(item[key]) for key in column_names))
-        return create_display_table(names, columns, column_names)
+
+        # pylint: disable-next=assignment-from-none
+        custom_table = self.create_custom_table(columns=column_names, data=columns)
+        return custom_table if custom_table else create_display_table(names, columns, column_names,
+                                                                      self.index_label.upper())
 
     def to_name(self, items: List[Dict[str, Any]]) -> List[str]:
-        return [item['name'] for item in items]
+        return [item[self.index_label] for item in items]
 
     def to_json(self, items: List[Dict[str, Any]]) -> List[Dict[str, Any]]:
         return items
@@ -115,18 +132,44 @@ class MCLIGetDisplay(ABC):
         ...
 
 
-def create_display_table(names: List[str], columns: List[Tuple[Any, ...]], column_names: List[str]) -> Table:
+def create_vertical_display_table(data: List[Tuple[Any, ...]], columns: List) -> Table:
+    grid = Table.grid(expand=True)
+    # left column is header, right column is data
+    grid.add_column(justify="left")
+    grid.add_column(justify="left")
+    for d in data:
+        for col, val in zip(columns, d):
+            grid.add_row(col, val)
+    return grid
 
-    output_table = create_table(data=columns,
-                                indices=names,
-                                index_label='NAME',
-                                columns=[ss.upper() for ss in column_names],
-                                table_kwargs={
-                                    'box': None,
-                                    'pad_edge': False
-                                },
-                                index_kwargs={
-                                    'justify': 'left',
-                                    'no_wrap': True
-                                })
-    return output_table
+
+def create_display_table(names: List[str],
+                         columns: List[Tuple[Any, ...]],
+                         column_names: List[str],
+                         index_label: str = 'NAME') -> Table:
+    return create_table(data=columns,
+                        indices=names,
+                        index_label=index_label,
+                        columns=[ss.upper() for ss in column_names],
+                        table_kwargs={
+                            'box': None,
+                            'pad_edge': False
+                        },
+                        index_kwargs={
+                            'justify': 'left',
+                            'no_wrap': True
+                        })
+
+
+def format_timestamp(timestamp: Optional[datetime.datetime], default='-') -> str:
+    """Format timestamps for printing
+    """
+
+    if not timestamp:
+        return default
+    tz = datetime.datetime.now(datetime.timezone.utc).astimezone().tzinfo
+    dt_format = '%Y-%m-%d %I:%M %p'
+    try:
+        return timestamp.astimezone(tz).strftime(dt_format)
+    except (OverflowError, ValueError) as _:
+        return default
