@@ -23,9 +23,11 @@ class MCLIEnvDisplay(MCLIGetDisplay):
 
     def __iter__(self) -> Generator[EnvDisplayItem, None, None]:
         for env_var in self.envs:
-            if env_var.name is None:
-                env_var.name = 'unknown_name'
-            yield EnvDisplayItem(name=env_var.name, key=env_var.key, value=env_var.value)
+            yield EnvDisplayItem(key=env_var.key, value=env_var.value)
+
+    @property
+    def index_label(self) -> str:
+        return "key"
 
 
 def get_environment_variables(output: OutputDisplay = OutputDisplay.TABLE, **kwargs) -> int:
