@@ -6,12 +6,14 @@ import textwrap
 import webbrowser
 from typing import Dict, List, NamedTuple, Optional
 
-from mcli.config import MCLI_KUBECONFIG
-from mcli.utils.utils_interactive import ValidationError, secret_prompt, simple_prompt
+from mcli.api.exceptions import ValidationError
+from mcli.cli.m_create.cluster import ClusterCreator, ClusterValidationError, create_one_cluster
+from mcli.config import MCLI_KUBECONFIG, MESSAGE, MCLIConfigError
+from mcli.utils.utils_interactive import secret_prompt, simple_prompt
 from mcli.utils.utils_logging import FAIL, OK, console
 from mcli.utils.utils_rancher import (ProjectInfo, configure_namespaces, generate_cluster_config, retrieve_clusters,
                                       retrieve_projects)
-from mcli.utils.utils_string_validation import validate_rfc1123_name
+from mcli.utils.utils_string_functions import validate_rfc1123_name
 
 RANCHER_ENDPOINT_PATTERN = 'https://rancher.z[0-9]+.r[0-9]+.mosaicml.cloud'
 LEGACY_RANCHER_ENDPOINT = 'https://mosaicml-rancher.westus2.cloudapp.azure.com'
@@ -32,7 +34,7 @@ def validate_rancher_endpoint(endpoint: str) -> bool:
         return True
     if endpoint == LEGACY_RANCHER_ENDPOINT:
         return True
-    raise RuntimeError(f'Invalid Rancher endpoint: {endpoint}. Should be of the form: '
+    raise RuntimeError(f'Invalid MosaicML Cloud endpoint: {endpoint}. Should be of the form: '
                        f'{RANCHER_ENDPOINT_PATTERN}')
 
 
@@ -68,7 +70,7 @@ def fill_rancher_values(
 ) -> RancherDetails:
     if not rancher_endpoint:
         zone = simple_prompt(
-            'Which Rancher "zone" would you like to access?',
+            'Which MosaicML Cloud "zone" would you like to access?',
             validate=validate_number,
         )
         rancher_endpoint = f'https://rancher.z{zone}.r0.mosaicml.cloud'
@@ -80,14 +82,18 @@ def fill_rancher_values(
         path = DEEP_LINKS.get(rancher_endpoint, None) or DEEP_LINKS['DEFAULT']
         url = f'{rancher_endpoint}/{path}'
         logger.info(
-            f'\n\nTo communicate with Rancher we\'ll need your API key (also called the "{bold("Bearer Token")}"). '
+            '\n\nTo communicate with the MosaicML Cloud we\'ll need your API key '
+            f'(also called the "{bold("Bearer Token")}"). '
             'Your browser should have opened to the API key creation screen. Login, if necessary, then, create a '
             f'key with "{bold("no scope")}" that expires "{bold("A day from now")}" and copy the '
             f'"{bold("Bearer Token")}" for this next step. If your browser did not open, please use this link:'
-            f'\n\n[blue]{url}[/]\n\n')
+            f'\n\n[blue]{url}[/]\n\n'
+            'If upon login you do not see the API key creation screen, either try the link above in Google Chrome or '
+            f'select "{bold("Accounts & API Keys")}" from the top-right user menu, followed by '
+            f'"{bold("Create API Key")}" and the directions above.')
         webbrowser.open_new_tab(url)
 
-        auth_token = secret_prompt('What is your Rancher "Bearer token"?', validate=validate_auth_token)
+        auth_token = secret_prompt('What is your "bearer token"?', validate=validate_auth_token)
 
     assert auth_token is not None
 
@@ -107,6 +113,7 @@ def initialize_k8s(
     namespace: Optional[str] = None,
     **kwargs,
 ) -> int:
+    # pylint: disable=too-many-statements
     del kwargs
 
     try:
@@ -129,7 +136,8 @@ def initialize_k8s(
         if clusters:
             logger.info(f'{OK} Found {len(clusters)} clusters that you have access to')
         else:
-            logger.error(f'{FAIL} No clusters found. Please double-check that you have access to clusters in Rancher')
+            logger.error(f'{FAIL} No clusters found. Please double-check that you have access to clusters in '
+                         'the MosaicML Cloud')
             return 1
 
         # Setup namespace
@@ -166,17 +174,31 @@ def initialize_k8s(
         logger.info(f'You now have access to {bold(str(len(clusters)))} new clusters: '
                     f'{cluster_names}')
 
-        if len(clusters) == 1:
-            create_platform_message = f'[bold]mcli create platform {clusters[0].name}[/]'
-        else:
-            create_platform_message = '[bold]mcli create platform --all[/]'
+        clusters_failed_creation = []
+        cluster_creator = ClusterCreator()
+        for cluster in clusters:
+            cluster_name = cluster.name
+            try:
+                create_one_cluster(creator=cluster_creator,
+                                   name=cluster_name,
+                                   kubernetes_context=cluster_name,
+                                   namespace=namespace)
+            except ClusterValidationError:
+                clusters_failed_creation.append(cluster_name)
+            except MCLIConfigError:
+                logger.error(MESSAGE.MCLI_NOT_INITIALIZED)
+                break
 
-        logger.info(
-            textwrap.dedent(f"""
-                You can now add your available cluster(s) to `mcli` using:
+        if len(clusters_failed_creation) > 0:
+            logger.info(
+                textwrap.dedent(f"""
+                    Cluster(s) {', '.join(clusters_failed_creation)} already exist. If these are already setup correctly, then nothing more is required.
 
-                {create_platform_message}
-                """))
+                    If you would like to update details on them, please delete them and recreate them with:
+
+                    [bold]mcli delete cluster {' '.join(clusters_failed_creation)}[/]
+                    [bold]mcli create cluster {' '.join(clusters_failed_creation)}[/]
+                    """))
 
     except RuntimeError as e:
         logger.error(f'{FAIL} {e}')
@@ -188,15 +210,15 @@ def initialize_k8s(
 def add_init_kube_parser(subparser: argparse._SubParsersAction):
     kube_init_parser: argparse.ArgumentParser = subparser.add_parser(
         'init-kube',
-        help='Configure your Kubernetes clusters using Rancher. These calls require access to Rancher, which you '
-        'should have as users of the MosaicML cloud.',
+        help='Configure your Kubernetes clusters in the MosaicML Cloud',
     )
-    kube_init_parser.add_argument('--auth-token', default=None, help='Your Rancher API key bearer token')
+    kube_init_parser.add_argument('--auth-token', default=None, help='Your bearer token')
     kube_init_parser.add_argument(
         '--endpoint',
         dest='rancher_endpoint',
         default=None,
-        help=f'The rancher instance URL of the form: {RANCHER_ENDPOINT_PATTERN}',
+        help=f'The Rancher instance URL of the form: {RANCHER_ENDPOINT_PATTERN}. This is only required for use cases '
+        'with advanced configuration requirements.',
     )
     kube_init_parser.add_argument(
         '--namespace',
