@@ -8,7 +8,7 @@ from mcli.utils.utils_serializable_dataclass import SerializableDataclass, T_Ser
 @dataclass
 class MCLIEnvVar(SerializableDataclass):
     # TODO(averylamp): This is a WIP to be flushed out more later
-    name: str
+    # The name of a MCLIEnvVar is its key
     key: str
     value: str
 
