@@ -2,6 +2,8 @@
 # pylint: disable=useless-import-alias
 
 from mcli.objects.integrations.apt_packages import MCLIAptPackagesIntegration as MCLIAptPackagesIntegration
+from mcli.objects.integrations.comet import MCLICometMLIntegration as MCLICometMLIntegration
 from mcli.objects.integrations.git_repo import MCLIGitRepoIntegration as MCLIGitRepoIntegration
+from mcli.objects.integrations.local import MCLILocalIntegration as MCLILocalIntegration
 from mcli.objects.integrations.pip_packages import MCLIPipPackagesIntegration as MCLIPipPackagesIntegration
 from mcli.objects.integrations.wandb import MCLIWandBIntegration as MCLIWandBIntegration
