@@ -1,11 +1,22 @@
 """Creators for docker secrets"""
+from enum import Enum
 from typing import Callable, Optional
 
 from mcli.models import SecretType
 from mcli.objects.secrets import MCLIDockerRegistrySecret
 from mcli.objects.secrets.create.base import SecretCreator, SecretValidationError
-from mcli.utils.utils_interactive import secret_prompt, simple_prompt
-from mcli.utils.utils_string_validation import validate_email_address, validate_url
+from mcli.utils.utils_interactive import choose_one, secret_prompt, simple_prompt
+from mcli.utils.utils_string_functions import validate_email_address, validate_url
+
+
+class ContainerRegistries(Enum):
+    DOCKERHUB = ("DockerHub", "https://index.docker.io/v1/")
+    GHCR = ("Github (GHCR)", "https://ghcr.io")
+    OTHER = ("Other", "")
+
+    def __init__(self, display: str, url: str):
+        self.display = display
+        self.url = url
 
 
 class DockerSecretFiller():
@@ -26,9 +37,14 @@ class DockerSecretFiller():
 
     @classmethod
     def fill_server(cls, validate: Callable[[str], bool]) -> str:
-        return cls.fill_str('What is the URL for this registry?',
-                            validate=validate,
-                            default='https://index.docker.io/v1/')
+        chosen = choose_one(message="Which container registry would you like to use?",
+                            options=list(ContainerRegistries),
+                            formatter=lambda o: o.display,
+                            default=ContainerRegistries.DOCKERHUB)
+        server = chosen.url
+        if chosen is ContainerRegistries.OTHER:
+            server = cls.fill_str('What is the URL for this registry?', validate=validate)
+        return server
 
 
 class DockerSecretValidator():
