@@ -11,7 +11,7 @@ from mcli.objects.secrets.create.generic import FileSecretFiller, FileSecretVali
 from mcli.objects.secrets.ssh import MCLISFTPSSHSecret
 from mcli.utils.utils_interactive import file_prompt, query_yes_no, simple_prompt
 from mcli.utils.utils_logging import WARN, console
-from mcli.utils.utils_string_validation import ensure_rfc1123_compatibility, validate_existing_filename
+from mcli.utils.utils_string_functions import ensure_rfc1123_compatibility, validate_existing_filename
 
 logger = logging.getLogger(__name__)
 
@@ -21,12 +21,13 @@ def _get_known_hosts_str(host_name: str) -> str:
         result = subprocess.run(["ssh-keyscan", host_name], capture_output=True, check=True)
         known_hosts_str = result.stdout.decode("utf-8")
         return known_hosts_str
-    except subprocess.CalledProcessError:
+    except subprocess.CalledProcessError as e:
         raise SecretValidationError(
-            f'ssh-keyscan failed. Please ensure that your hostname was spelled correctly and has an ssh port open on port 22.'
-        )
-    except FileNotFoundError:
-        raise SecretValidationError(f'ssh-keyscan failed. Please ensure that you have ssh installed on your machine.')
+            'ssh-keyscan failed. '
+            'Please ensure that your hostname was spelled correctly and has an ssh port open on port 22.') from e
+    except FileNotFoundError as e:
+        raise SecretValidationError(
+            'ssh-keyscan failed. Please ensure that you have ssh installed on your machine.') from e
 
 
 class SSHSecretFiller(FileSecretFiller):
@@ -81,7 +82,7 @@ class SSHSecretValidator(FileSecretValidator):
     @staticmethod
     def validate_host_name(host_name: str) -> bool:
         if not host_name:
-            raise SecretValidationError(f'Host name must be specified.')
+            raise SecretValidationError('Host name must be specified.')
         return True
 
 
