@@ -3,7 +3,7 @@ from __future__ import annotations
 
 from dataclasses import dataclass
 from pathlib import Path
-from typing import List, Optional, Set, Type
+from typing import Any, Dict, List, Optional, Set, Type
 
 from kubernetes import client
 
@@ -36,6 +36,18 @@ class MCLIMountedSecret(MCLIGenericSecret):
         if self.mount_path is None:
             self.mount_path = str(SECRET_MOUNT_PATH_PARENT / self.name)
 
+    @property
+    def mapi_data(self) -> Dict[str, Any]:
+        return {
+            'mountedSecret': {
+                'name': self.name,
+                'metadata': {
+                    'mountPath': self.mount_path
+                },
+                'value': self.value,
+            },
+        }
+
     @property
     def required_packing_fields(self) -> Set[str]:
         return set(self.disk_skipped_fields + ['mount_path'])
