@@ -1,11 +1,11 @@
 """ SSH Secret Type """
 from dataclasses import dataclass
 from pathlib import Path
-from typing import List, Optional, Set
+from typing import Any, Dict, List, Optional, Set
 
 from kubernetes import client
 
-from mcli.objects.secrets import MCLIMountedSecret
+from mcli.objects.secrets.mounted import MCLIMountedSecret
 from mcli.serverside.job.mcli_k8s_job import MCLIK8sJob
 
 # Environment variable used by Composer to point to the path of the private key
@@ -26,6 +26,18 @@ class MCLISSHSecret(MCLIMountedSecret):
     def add_to_job(self, kubernetes_job: MCLIK8sJob, permissions: int = 256) -> bool:
         return super().add_to_job(kubernetes_job=kubernetes_job, permissions=permissions)
 
+    @property
+    def mapi_data(self) -> Dict[str, Any]:
+        return {
+            'sshSecret': {
+                'name': self.name,
+                'metadata': {
+                    'mountPath': self.mount_path,
+                },
+                'value': self.value,
+            },
+        }
+
 
 @dataclass
 class MCLIGitSSHSecret(MCLISSHSecret):
@@ -35,6 +47,18 @@ class MCLIGitSSHSecret(MCLISSHSecret):
     will be pointed toward it
     """
 
+    @property
+    def mapi_data(self) -> Dict[str, Any]:
+        return {
+            'gitSSHSecret': {
+                'name': self.name,
+                'metadata': {
+                    'mountPath': self.mount_path,
+                },
+                'value': self.value,
+            },
+        }
+
     def add_to_job(self, kubernetes_job: MCLIK8sJob, permissions: int = 256) -> bool:
         super().add_to_job(kubernetes_job=kubernetes_job, permissions=permissions)
         assert self.mount_path is not None
@@ -56,6 +80,18 @@ class MCLISFTPSSHSecret(MCLISSHSecret):
 
     known_hosts: Optional[str] = None
 
+    @property
+    def mapi_data(self) -> Dict[str, Any]:
+        return {
+            'sftpSSHSecret': {
+                'name': self.name,
+                'metadata': {
+                    'mountPath': self.mount_path,
+                },
+                'value': self.value,
+            },
+        }
+
     @property
     def required_packing_fields(self) -> Set[str]:
         return super().required_packing_fields.union(set(['known_hosts']))
