@@ -6,6 +6,7 @@ from typing import Any, Callable, List, Optional, TypeVar, Union, overload
 import questionary
 from typing_extensions import Literal
 
+from mcli.api.exceptions import InputDisabledError, ValidationError
 from mcli.utils.utils_logging import err_console
 
 T_Option = TypeVar('T_Option')  # pylint: disable=invalid-name
@@ -28,12 +29,7 @@ STYLE = questionary.Style([
 ])
 
 _INPUT_DISABLED: bool = False
-_INPUT_DISABLED_MESSAGE: str = 'Interactivity requested when input was disabled'
-
-
-class ValidationError(Exception):
-    """Base class for interactive validation errors
-    """
+_INPUT_DISABLED_MESSAGE: str = 'Found missing arguments when using `--no-input`'
 
 
 def _get_validation_callback(validation_fun: Callable[[str], bool]) -> Callable[[str], Union[bool, str]]:
@@ -60,11 +56,6 @@ def _get_validation_callback(validation_fun: Callable[[str], bool]) -> Callable[
     return validator
 
 
-class InputDisabledError(Exception):
-    """Error thrown when interactivity is requested but input has been disabled.
-    """
-
-
 class input_disabled():
     """Context manager for enabling or disabling input
 
@@ -142,7 +133,7 @@ def check_input_disabled(func):
 @check_input_disabled
 def query_yes_no(
     message: str,
-    default: bool = True,
+    default: bool = False,
 ):
     """A simple yes or no question for the user
 
@@ -283,7 +274,7 @@ def file_prompt(message: str,
         default: Default value for the user input. Defaults to None.
         mandatory: If True, the user will be required to answer the question. Defaults to True.
         validate: Validation function called on the user's input. The function should
-            raise a ValidatinonError if the input is not valid and the error message will
+            raise a ValidationError if the input is not valid and the error message will
             be presented to the user. Defaults to None for no validation.
 
     Returns:
@@ -349,4 +340,5 @@ def choose_one(message: str,
         choices,
         style=STYLE,
         pointer='➤',
+        qmark='? ',
     ).unsafe_ask()
