@@ -1,13 +1,10 @@
 """ MCLI Versioning """
 from __future__ import annotations
 
+import logging
 from typing import NamedTuple
 
-__version_major__ = 0
-__version_minor__ = 2
-__version_patch__ = 1
-__version_extras__ = ''
-__version__ = f'v{__version_major__}.{__version_minor__}.{__version_patch__}{__version_extras__}'
+logger = logging.getLogger(__name__)
 
 
 class Version(NamedTuple):
@@ -63,7 +60,6 @@ class Version(NamedTuple):
         Returns:
             Returns a Version object
         """
-        text = text.lstrip('v')
         major, minor, patch = text.split('.')
         extras = ''
         if not patch.isdigit():
@@ -78,14 +74,50 @@ class Version(NamedTuple):
         )
 
     def __str__(self) -> str:
-        return f'v{self.major}.{self.minor}.{self.patch}{self.extras}'
+        return f'{self.major}.{self.minor}.{self.patch}{self.extras}'
 
     @property
     def is_alpha(self) -> bool:
         return self.extras != ''
 
 
-def print_version(**kwargs) -> int:
+def get_formatted_version() -> str:
+    """ Return version number as a string """
+    # pylint: disable=import-outside-toplevel
+    from mcli.config import FeatureFlag, MCLIConfig
+    from mcli.utils.utils_pypi import get_latest_alpha_package_version, get_latest_package_version
+
+    latest_version = current_version = Version.from_string(__version__)
+    conf = MCLIConfig.load_config(safe=True)
+    is_alpha = current_version.is_alpha or conf.feature_enabled(FeatureFlag.ALPHA_TESTER)
+    version_output = ""
+    try:
+        if is_alpha:
+            latest_version = get_latest_alpha_package_version()
+        else:
+            latest_version = get_latest_package_version()
+    except Exception:  # pylint: disable=broad-except
+        return 'Failed to fetch current version from PyPI.'
+
+    if latest_version > current_version:
+        version_output += f'Your current version is ({current_version}), and a new version ({latest_version}) ' + \
+                          'is available, please upgrade with: ' + \
+                          f'\033[1mpip install --upgrade mosaicml-cli=={str(latest_version).lstrip("v")}\033[0m. '
+    else:
+        version_output += 'Your version is up to date. MosaicML CLI (MCLI) ' + str(latest_version)
+
+    return version_output
+
+
+def print_version(**kwargs) -> None:
+    """ Prints version """
     del kwargs
-    print(__version__)
-    return 0
+    print(get_formatted_version())
+
+
+__version__ = "0.2.37"
+v = Version.from_string(__version__)
+__version_major__ = v.major
+__version_minor__ = v.minor
+__version_patch__ = v.patch
+__version_extras__ = v.extras
